# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  imports =
    [
      ../../modules

      # Include the results of the hardware scan.
      ./hardware-configuration.nix
    ];

  # Bootloader.
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;

  # Define a user account. Don't forget to set a password with ‘passwd’.
  users.users.florian = {
    isNormalUser = true;
    description = "florian";
    extraGroups = [ "networkmanager" "wheel" ];
  };
  home-manager.users.florian = {
    home = {
      username = "florian";
      homeDirectory = "/home/florian";

      stateVersion = "24.05";
    };

    programs.home-manager.enable = true;
    nix.settings.experimental-features = [ "nix-command" "flakes" ];
  };

  networking.hostName = "nixos-laptop-pro"; # Define your hostname.

  hardware.nvidia.prime = {
    offload = {
      enable = true;
      enableOffloadCmd = true;
    };

    # Make sure to use the correct Bus ID values for your system!
    # information bus: pci@0000:00:02.0
    intelBusId = "PCI:0:2:0";
    # information bus: pci@0000:01:00.0
    nvidiaBusId = "PCI:1:0:0";
  };
}
